﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Practices.Composite.Events;
using EventAggregation.Infrastructure;

namespace SaveAsPodcastModule.Views
{
    /// <summary>
    /// Interaction logic for UserControl1.xaml
    /// </summary>
    public partial class SaveAsPodcastView : UserControl
    {
        private PodcastEpisodeListViewModel _selectedPodcastEpisodeListItems = new PodcastEpisodeListViewModel();
        private readonly IEventAggregator _eventAggregator;
        
        public SaveAsPodcastView(IEventAggregator eventAggregator)
        {
            _eventAggregator = eventAggregator;
            InitializeComponent();

            // For DATA BINDING
            this.Episodes.ItemsSource = _selectedPodcastEpisodeListItems;
        }

        private void PodcastFeeds_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            string feedUrl = ((this.PodcastFeeds.SelectedItem as ListBoxItem).Content as TextBlock).Text;
            var podcastFeedLoader = new PodcastFeedGetter();
            var episodes = podcastFeedLoader.GetEpisodes(feedUrl);
#if false
            foreach (var episode in episodes)
            {
                PodcastEpisode pe = PodcastEpisodeBuilder.BuildPodcastEpisode(episode);
                string episodeTitle = episode.Element("title").Value;
                this.Episodes.Items.Add(episodeTitle);
            }
#else            
            foreach (var episode in episodes)
            {
                PodcastEpisode pe = new PodcastEpisode(episode);
                PodcastEpisodeViewModel peVM = new PodcastEpisodeViewModel(pe);
                _selectedPodcastEpisodeListItems.Add(peVM);
            }
#endif
        }

        private void Episodes_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // grab current item data from Episodes ListBox, 
            // stuff into CollectedEpisodes list
            PodcastEpisodeViewModel peVM = Episodes.SelectedItem as PodcastEpisodeViewModel;
            if (peVM == null) return;
            string episodeName = peVM.Title;
            if (episodeName == null) return;
            // PROBLEM: how to I get access to other data fields?
            // EXAMPLE: I want the MediaUrl, which is not displayed
        ////    CollectedEpisodes.Items.Add(new TextBlock().Text = episodeName);

            EventAggregation.Infrastructure.CollectedPodcastEpisode cpe = new EventAggregation.Infrastructure.CollectedPodcastEpisode()
            {
                CollectionTime = DateTime.Now,
                MediaURL = peVM.MediaURL,
                MimeType = peVM.MimeType
            };

            _eventAggregator.GetEvent<PodcastEpisodeCollectedEvent>().Publish(cpe);
        }
    }
}
